pub enum WatchdogAttemptStatus {
Dispatched,
Running,
}Expand description
Status of the watchdog attempt paired with a committed successor.
Variants
Dispatched
The scheduler committed the work callback, which has not committed a start.
Running
The accepted work callback is currently executing synchronously.