pub enum WatchdogRuntimeStateSnapshot {
Scheduled {
scheduler_generation: u64,
deadline_ns: u64,
},
AwaitingWork {
successor_generation: u64,
successor_deadline_ns: u64,
attempt: WatchdogAttemptSnapshot,
},
}Expand description
Coherent watchdog timer state.
Variants
Scheduled
One scheduler generation is authoritative and no work is outstanding.
Fields
AwaitingWork
A successor is authoritative while one work attempt is outstanding.