pub struct TimerOutcomeSnapshot { /* private fields */ }Expand description
Latest outcome and functional failure state for one timer.
Implementations
Sourceimpl TimerOutcomeSnapshot
impl TimerOutcomeSnapshot
Sourcepub const fn last_outcome(self) -> Option<TimerLastOutcome>
pub const fn last_outcome(self) -> Option<TimerLastOutcome>
Return the latest terminal event.
Sourcepub const fn last_work_count(self) -> Option<u64>
pub const fn last_work_count(self) -> Option<u64>
Return work reported by the latest completion.
Sourcepub const fn last_success_at_ns(self) -> Option<u64>
pub const fn last_success_at_ns(self) -> Option<u64>
Return the latest successful or valid no-work completion time.
Sourcepub const fn last_failure_at_ns(self) -> Option<u64>
pub const fn last_failure_at_ns(self) -> Option<u64>
Return the latest expected or invariant failure completion time.
Sourcepub const fn last_unacknowledged_at_ns(self) -> Option<u64>
pub const fn last_unacknowledged_at_ns(self) -> Option<u64>
Return when a dispatched watchdog attempt was most recently retired.
Sourcepub const fn consecutive_expected_failures(self) -> u64
pub const fn consecutive_expected_failures(self) -> u64
Return consecutive retryable failures since the latest reset outcome.