pub struct MemoryPageSample { /* private fields */ }Expand description
Page extents observed at the start and end of one normally completed callback.
Implementations
Sourceimpl MemoryPageSample
impl MemoryPageSample
Sourcepub const fn start(self) -> MemoryPageExtent
pub const fn start(self) -> MemoryPageExtent
Return page extents sampled at callback start.
Sourcepub const fn end(self) -> MemoryPageExtent
pub const fn end(self) -> MemoryPageExtent
Return page extents sampled after normal callback completion.
Sourcepub const fn wasm_growth_pages(self) -> u64
pub const fn wasm_growth_pages(self) -> u64
Return non-negative Wasm-memory page growth observed between samples.
For async ordinary work, the interval may include interleaved canister activity while the callback future is awaiting.
Sourcepub const fn stable_growth_pages(self) -> u64
pub const fn stable_growth_pages(self) -> u64
Return non-negative stable-memory page growth observed between samples.
For async ordinary work, the interval may include interleaved canister activity while the callback future is awaiting.